SynthDefs
=========

- what is a synthdef
- sclang vs supriya implementation

Concepts
--------

- synthdefs
- ugens
- calculation rates
- inputs and outputs (and buses)
- parameters and controls
- multi-channel expansion

Building
--------

- context managers
- ugen "capture"
- parameters
- multi-channel expansion
- names

Inspection
----------

- printing
- graphing

Lifecycle
---------

- allocation
- freeing
